Add

Struct Add 

pub struct Add { /* private fields */ }
p4 [g-opts] add [-c changelist] [-d -f -I -n] [-t filetype] file ...

Open files in a client workspace for addition to the depot.

Implementations

Source

impl Add

pub fn new(bin: impl Into<PathBuf>, global_opts: GlobalOpts) -> Self

Open files in a client workspace for addition to the depot.

bin is the path to the Perforce command-line executable.

pub fn get_global_opts(&self) -> &GlobalOpts

Description

g-opts

See Global options.

pub fn set_global_opts(&mut self, v: GlobalOpts) -> &mut Self

Description

g-opts

See Global options.

pub fn global_opts(self, v: GlobalOpts) -> Self

Description

g-opts

See Global options.

pub fn get_change_list(&self) -> Option<&String>

Description

-c changelist

Opens the files for add within the specified changelist. If this option is not used, the files are linked to the default changelist.

pub fn set_change_list(&mut self, v: impl Into<String>) -> &mut Self

Description

-c changelist

Opens the files for add within the specified changelist. If this option is not used, the files are linked to the default changelist.

pub fn change_list(self, v: impl Into<String>) -> Self

Description

-c changelist

Opens the files for add within the specified changelist. If this option is not used, the files are linked to the default changelist.

pub fn get_downgrade(&self) -> bool

Description

-d

Downgrade file open status to simple add.

pub fn set_downgrade(&mut self, v: bool) -> &mut Self

Description

-d

Downgrade file open status to simple add.

pub fn downgrade(self, v: bool) -> Self

Description

-d

Downgrade file open status to simple add.

pub fn get_force_literal_filenames(&self) -> bool

Description

-f

Use the -f option to force inclusion of wildcards in filenames. See File specifications for details.

Filenames that contain the special characters ‘@’, ‘#’, ‘%’, or ‘*’ are reformatted to encode the characters using ASCII hexadecimal representation. After the files are added, refer to them using the reformatted file name instead of the local file system name.

pub fn set_force_literal_filenames(&mut self, v: bool) -> &mut Self

Description

-f

Use the -f option to force inclusion of wildcards in filenames. See File specifications for details.

Filenames that contain the special characters ‘@’, ‘#’, ‘%’, or ‘*’ are reformatted to encode the characters using ASCII hexadecimal representation. After the files are added, refer to them using the reformatted file name instead of the local file system name.

pub fn force_literal_filenames(self, v: bool) -> Self

Description

-f

Use the -f option to force inclusion of wildcards in filenames. See File specifications for details.

Filenames that contain the special characters ‘@’, ‘#’, ‘%’, or ‘*’ are reformatted to encode the characters using ASCII hexadecimal representation. After the files are added, refer to them using the reformatted file name instead of the local file system name.

pub fn get_skip_ignore(&self) -> bool

Description

-I

Do not perform any ignore checking; ignore any settings specified by P4IGNORE.

pub fn set_skip_ignore(&mut self, v: bool) -> &mut Self

Description

-I

Do not perform any ignore checking; ignore any settings specified by P4IGNORE.

pub fn skip_ignore(self, v: bool) -> Self

Description

-I

Do not perform any ignore checking; ignore any settings specified by P4IGNORE.

pub fn get_preview(&self) -> bool

Description

-n

Preview which files would be opened for add, without actually changing any files or metadata.

pub fn set_preview(&mut self, v: bool) -> &mut Self

Description

-n

Preview which files would be opened for add, without actually changing any files or metadata.

pub fn preview(self, v: bool) -> Self

Description

-n

Preview which files would be opened for add, without actually changing any files or metadata.

pub fn get_filetype(&self) -> Option<&String>

Description

-t filetype

Adds the file as the specified filetype, overriding any settings in the typemap table. See Base file types and modifiers as well as the lbr.autocompress configurable.

pub fn set_filetype(&mut self, v: impl Into<String>) -> &mut Self

Description

-t filetype

Adds the file as the specified filetype, overriding any settings in the typemap table. See Base file types and modifiers as well as the lbr.autocompress configurable.

pub fn filetype(self, v: impl Into<String>) -> Self

Description

-t filetype

Adds the file as the specified filetype, overriding any settings in the typemap table. See Base file types and modifiers as well as the lbr.autocompress configurable.