Skip to main content Module admin Copy item path Source compression reconcile Variants of the [--restrict-only | --expand-only] mutually exclusive
option group of p4 admin replica-filter-reconcile. set_password Variants of the {-a | -u user} mutually exclusive option group of
p4 admin resetpassword. spec Variants of the [-a | -s type] mutually exclusive option group of
p4 admin updatespecdepot. Admin A p4 admin operation wrapping a selected SubCommand . AdminEntry Entry point for the p4 admin subcommands. CheckPoint p4 admin checkpoint [-z | -Z] [-p [-N threads] [-m]] [prefix]: take a checkpoint.
The C type parameter encodes the compression mode (none, -z, or
-Z) at compile time; see ExclusiveOption .EndJournal p4 admin end-journal: end journal replication at a failover consistency
point. Added in p4 2018.1.Journal p4 admin journal [-z] [prefix]: rotate the journal.ReplicaFilterReconcile p4 admin replica-filter-reconcile [--restrict-only | --expand-only] [table ...]: reconcile the replica database after filter changes. Added in
p4 2025.2.ResetPassword p4 admin resetpassword {-a | -u user} [-l]: force users to reset their
passwords.ResourceMonitor p4 admin resource-monitor: report server resource usage. Added in p4
2023.1.Restart p4 admin restart: restart the Perforce service.SetLdapUsers p4 admin setldapusers: convert existing non-super users to LDAP
authentication. Added in p4 2015.1.Stop p4 admin stop: stop the Perforce service.SysInfo p4 admin sysinfo: dump system information for Perforce Support. Added in
p4 2023.1.UpdateSpecDepot p4 admin updatespecdepot [-a | -s type]: archive forms into the spec
depot.SpecifiedType The form specification type archived by p4 admin updatespecdepot -s.