Admin

Struct Admin 

pub struct Admin<T: SubCommand> { /* private fields */ }
A p4 admin operation wrapping a selected SubCommand.

Implementations

Source

impl<T: SubCommand> Admin<T>

pub fn new( bin: impl Into<PathBuf>, global_opts: GlobalOpts, sub_command: T, ) -> Self

Creates a p4 admin command wrapping the given subcommand.

bin is the path to the Perforce command-line executable.

pub fn get_global_opts(&self) -> &GlobalOpts

Description

g-opts

See Global options.

pub fn set_global_opts(&mut self, v: GlobalOpts) -> &mut Self

Description

g-opts

See Global options.

pub fn global_opts(self, v: GlobalOpts) -> Self

Description

g-opts

See Global options.

Source

impl<C: ExclusiveOption> Admin<CheckPoint<C>>

pub fn get_parallel(&self) -> bool

Description

-p

Requests a parallel checkpoint.

pub fn set_parallel(&mut self, parallel: bool) -> &mut Self

Description

-p

Requests a parallel checkpoint.

pub fn parallel(self, parallel: bool) -> Self

Description

-p

Requests a parallel checkpoint.

pub fn get_threads(&self) -> Option<&u32>

Description

-N threads

Specifies the number of threads to use during the parallel request.

pub fn set_threads(&mut self, threads: u32) -> &mut Self

Description

-N threads

Specifies the number of threads to use during the parallel request.

pub fn threads(self, threads: u32) -> Self

Description

-N threads

Specifies the number of threads to use during the parallel request.

pub fn get_multiple_files(&self) -> bool

Description

-m

Uses multiple files if there are multiple parallel threads because db.checkpoint.threads is greater than 1 or the -N option is greater than 1. See Parallel checkpointing, dumping and recovery in the P4 Server Administration Documentation. See also Checkpoint examples.

pub fn set_multiple_files(&mut self, multiple_files: bool) -> &mut Self

Description

-m

Uses multiple files if there are multiple parallel threads because db.checkpoint.threads is greater than 1 or the -N option is greater than 1. See Parallel checkpointing, dumping and recovery in the P4 Server Administration Documentation. See also Checkpoint examples.

pub fn multiple_files(self, multiple_files: bool) -> Self

Description

-m

Uses multiple files if there are multiple parallel threads because db.checkpoint.threads is greater than 1 or the -N option is greater than 1. See Parallel checkpointing, dumping and recovery in the P4 Server Administration Documentation. See also Checkpoint examples.

Source

impl Admin<CheckPoint<Unselected>>

pub fn compress_both(self) -> Admin<CheckPoint<Both>>

Description

-z

Save the checkpoint and journal file in compressed format. The .gz suffix is appended to compressed journals and checkpoint files, which are in gzip format. If you do not specify -z or -Z, no compression occurs.

pub fn compress_checkpoint_only(self) -> Admin<CheckPoint<CheckPointOnly>>

Description

-Z

For p4 admin checkpoint -Z, save the checkpoint in compressed format, but leave the journal uncompressed for use by replica servers. The .gz suffix is appended to compressed journals and checkpoint files, which are in gzip format. If you do not specify -z or -Z, no compression occurs.

Source

impl Admin<Journal>

pub fn get_gzip(&self) -> bool

Description

-z

Save the journal file in compressed format. The .gz suffix is appended to compressed journals and checkpoint files, which are in gzip format. If you do not specify -z, no compression occurs.

pub fn set_gzip(&mut self, gzip: bool) -> &mut Self

Description

-z

Save the journal file in compressed format. The .gz suffix is appended to compressed journals and checkpoint files, which are in gzip format. If you do not specify -z, no compression occurs.

pub fn gzip(self, gzip: bool) -> Self

Description

-z

Save the journal file in compressed format. The .gz suffix is appended to compressed journals and checkpoint files, which are in gzip format. If you do not specify -z, no compression occurs.

Source

impl Admin<UpdateSpecDepot<Unselected>>

pub fn all(self) -> Admin<UpdateSpecDepot<All>>

Description

-a

For p4 admin updatespecdepot -a, update the spec depot with all current forms.

pub fn specified_type( self, specified_type: SpecifiedType, ) -> Admin<UpdateSpecDepot<Selected>>

Description

-s type

For p4 admin updatespecdepot -s, update the spec depot with forms of the specified type, where type is one of client, depot, repo, branch, label, typemap, group, user, job, stream, triggers, protect, server, license, or jobspec.

Source

impl Admin<UpdateSpecDepot<Selected>>

pub fn get_specified_type(&self) -> &SpecifiedType

Description

-s type

For p4 admin updatespecdepot -s, update the spec depot with forms of the specified type, where type is one of client, depot, repo, branch, label, typemap, group, user, job, stream, triggers, protect, server, license, or jobspec.

pub fn set_specified_type(&mut self, specified_type: SpecifiedType) -> &mut Self

Description

-s type

For p4 admin updatespecdepot -s, update the spec depot with forms of the specified type, where type is one of client, depot, repo, branch, label, typemap, group, user, job, stream, triggers, protect, server, license, or jobspec.

Source

impl Admin<ResetPassword<Unselected>>

pub fn all(self) -> Admin<ResetPassword<All>>

Description

-a

All users.

pub fn user(self, user: impl Into<String>) -> Admin<ResetPassword<User>>

Description

-u user

The specified user.

Source

impl Admin<ResetPassword<User>>

pub fn get_user(&self) -> &str

Description

-u user

The specified user.

pub fn set_user(&mut self, user: impl Into<String>) -> &mut Self

Description

-u user

The specified user.

Source

impl<T: ExclusiveOption> Admin<ResetPassword<T>>

pub fn get_super_user(&self) -> bool

Description

-l

Super user.

pub fn set_super_user(&mut self, super_user: bool) -> &mut Self

Description

-l

Super user.

pub fn super_user(self, super_user: bool) -> Self

Description

-l

Super user.

Source

impl Admin<ReplicaFilterReconcile<Unselected>>

pub fn restrict_only(self) -> Admin<ReplicaFilterReconcile<RestrictOnly>>

Description

–restrict-only

Reconcile the replica database by only removing applicable database records.

pub fn expand_only(self) -> Admin<ReplicaFilterReconcile<ExpandOnly>>

Description

–expand-only

Reconcile the replica database by only adding applicable database records.