Annotate

Struct Annotate 

pub struct Annotate<F = Unselected> { /* private fields */ }
p4 [g-opts] annotate [-a -c -i -I -q -t -T -u] [-d options] FileSpec[revSpec]: print file lines along with their revisions.

Implementations

Source

impl Annotate<Unselected>

pub fn new(bin: impl Into<PathBuf>, global_opts: GlobalOpts) -> Self

Creates a new p4 annotate command.

bin is the path to the Perforce command-line executable.

pub fn follow_branches(self) -> Annotate<Branches>

Description

-i

Follow file history across branches. If a file was created by branching, the output includes revisions up to the branch point. The use of the -i option implies the -c option. The -i option cannot be combined with -I.

pub fn follow_integrations(self) -> Annotate<Integrations>

Description

-I

Follow integrations into the file. If a line was introduced into the file by a merge, the source of the merge is indicated as the changelist that introduced the line. If that source was itself the result of an integration, that source will be used instead. The use of the -I option implies the -c option. The -I option cannot be combined with -i.

Source

impl<F: ExclusiveOption> Annotate<F>

pub fn get_global_opts(&self) -> &GlobalOpts

Description

g-opts

See Global options.

pub fn set_global_opts(&mut self, v: GlobalOpts) -> &mut Self

Description

g-opts

See Global options.

pub fn global_opts(self, v: GlobalOpts) -> Self

Description

g-opts

See Global options.

pub fn get_all_lines(&self) -> bool

Description

-a

All lines, including deleted lines and lines no longer present at the head revision, are included. Each line includes a starting and ending revision.

pub fn set_all_lines(&mut self, v: bool) -> &mut Self

Description

-a

All lines, including deleted lines and lines no longer present at the head revision, are included. Each line includes a starting and ending revision.

pub fn all_lines(self, v: bool) -> Self

Description

-a

All lines, including deleted lines and lines no longer present at the head revision, are included. Each line includes a starting and ending revision.

pub fn get_changelist_number(&self) -> bool

Description

-c

Display the changelist number, rather than the revision number, associated with each line. If you use the -a option and the -c option together, each line includes a starting and ending changelist number.

pub fn set_changelist_number(&mut self, v: bool) -> &mut Self

Description

-c

Display the changelist number, rather than the revision number, associated with each line. If you use the -a option and the -c option together, each line includes a starting and ending changelist number.

pub fn changelist_number(self, v: bool) -> Self

Description

-c

Display the changelist number, rather than the revision number, associated with each line. If you use the -a option and the -c option together, each line includes a starting and ending changelist number.

pub fn get_diff_options(&self) -> Option<&DiffOptions>

Description

-d options

Runs the diff routine with one of a subset of the standard UNIX diff options. See Usage notes for a listing of these options.

pub fn set_diff_options(&mut self, v: impl Into<DiffOptions>) -> &mut Self

Description

-d options

Runs the diff routine with one of a subset of the standard UNIX diff options. See Usage notes for a listing of these options.

pub fn diff_options(self, v: impl Into<DiffOptions>) -> Self

Description

-d options

Runs the diff routine with one of a subset of the standard UNIX diff options. See Usage notes for a listing of these options.

pub fn get_quiet_mode(&self) -> bool

Description

-q

Quiet mode, which suppresses the one-line header for each file.

pub fn set_quiet_mode(&mut self, v: bool) -> &mut Self

Description

-q

Quiet mode, which suppresses the one-line header for each file.

pub fn quiet_mode(self, v: bool) -> Self

Description

-q

Quiet mode, which suppresses the one-line header for each file.

pub fn get_force_binary(&self) -> bool

Description

-t

Force p4 annotate to display non-text (binary) files.

pub fn set_force_binary(&mut self, v: bool) -> &mut Self

Description

-t

Force p4 annotate to display non-text (binary) files.

pub fn force_binary(self, v: bool) -> Self

Description

-t

Force p4 annotate to display non-text (binary) files.

pub fn get_user_date(&self) -> bool

Description

-u

Display the name of the user who modified the change and the date when the modification occurred.

pub fn set_user_date(&mut self, v: bool) -> &mut Self

Description

-u

Display the name of the user who modified the change and the date when the modification occurred.

pub fn user_date(self, v: bool) -> Self

Description

-u

Display the name of the user who modified the change and the date when the modification occurred.

pub fn get_tab(&self) -> Option<u32>

Description

-T | --tab=N

Align output to a tab stop of 8. You can specify a different tab value using the --tab option and specifying the desired value for N.

Returns the tab stop currently set, or None if no tab option is set.

pub fn set_tab(&mut self, v: u32) -> &mut Self

Description

--tab=N

Align output to a tab stop of N. Use Self::set_default_tab to align output to the default tab stop of 8 with -T.

pub fn tab(self, v: u32) -> Self

Description

--tab=N

Align output to a tab stop of N. Use Self::default_tab to align output to the default tab stop of 8 with -T.

pub fn set_default_tab(&mut self) -> &mut Self

Description

-T

Align output to a tab stop of 8. Use Self::set_tab to align output to a different tab stop with --tab=N.

pub fn default_tab(self) -> Self

Description

-T

Align output to a tab stop of 8. Use Self::tab to align output to a different tab stop with --tab=N.