Archive

Struct Archive 

pub struct Archive<S = SafeArchive> { /* private fields */ }
p4 [g-opts] archive [-n -h -p -q -t -z] -D depot File Spec[revSpec]: archive obsolete revisions to an archive depot.

The S type parameter tracks the operation mode at compile time; see SafeArchive, PhysicalPurge, and Self::purge_physical_files.

Implementations

Source

impl Archive<SafeArchive>

pub fn new(bin: impl Into<PathBuf>, global_opts: GlobalOpts) -> Self

Creates a new p4 archive command.

bin is the path to the Perforce command-line executable.

pub fn purge_physical_files(self) -> Archive<PhysicalPurge>

Description

-p

For the specified files in the archive depot, remove the physical file revisions but retain the revision history with the latest action being set to purge. File contents are no longer accessible from p4 restore.

If you want to retain the metadata of purged files, do one of the following:

  • use the -p option of p4 obliterate (recommended)
  • perform the two-step sequence of p4 archive followed by p4 archive -p (time-consuming)

Transitions this command to the PhysicalPurge state, in which the -h and -z options are not available; any -h/-z selection made in the SafeArchive state is discarded.

Source

impl<M> Archive<M>
where Archive<M>: SubCommand,

pub fn get_global_opts(&self) -> &GlobalOpts

Description

g-opts

See Global options.

pub fn set_global_opts(&mut self, v: GlobalOpts) -> &mut Self

Description

g-opts

See Global options.

pub fn global_opts(self, v: GlobalOpts) -> Self

Description

g-opts

See Global options.

pub fn get_depot(&self) -> Option<&String>

Description

-D depot

Specify an archive depot to which files are to be archived.

pub fn set_depot(&mut self, v: impl Into<String>) -> &mut Self

Description

-D depot

Specify an archive depot to which files are to be archived.

pub fn depot(self, v: impl Into<String>) -> Self

Description

-D depot

Specify an archive depot to which files are to be archived.

pub fn get_preview(&self) -> bool

Description

-n

Do not archive revisions. Instead, report on which revisions would have been archived.

pub fn set_preview(&mut self, v: bool) -> &mut Self

Description

-n

Do not archive revisions. Instead, report on which revisions would have been archived.

pub fn preview(self, v: bool) -> Self

Description

-n

Do not archive revisions. Instead, report on which revisions would have been archived.

pub fn get_quiet_mode(&self) -> bool

Description

-q

Quiet mode, which suppresses messages about skipped revisions.

pub fn set_quiet_mode(&mut self, v: bool) -> &mut Self

Description

-q

Quiet mode, which suppresses messages about skipped revisions.

pub fn quiet_mode(self, v: bool) -> Self

Description

-q

Quiet mode, which suppresses messages about skipped revisions.

pub fn get_archive_delta(&self) -> bool

Description

-t

Archive text files (or other revisions stored in delta format, such as files of type binary+D)

pub fn set_archive_delta(&mut self, v: bool) -> &mut Self

Description

-t

Archive text files (or other revisions stored in delta format, such as files of type binary+D)

pub fn archive_delta(self, v: bool) -> Self

Description

-t

Archive text files (or other revisions stored in delta format, such as files of type binary+D)

Source

impl Archive<SafeArchive>

pub fn get_skip_head_revisions(&self) -> bool

Description

-h

Do not archive head revisions.

pub fn set_skip_head_revisions(&mut self, v: bool) -> &mut Self

Description

-h

Do not archive head revisions.

pub fn skip_head_revisions(self, v: bool) -> Self

Description

-h

Do not archive head revisions.

pub fn get_include_lazy_copies(&self) -> bool

Description

-z

Includes any files that have lazy copies or are lazy copies. See Criteria with -z.

pub fn set_include_lazy_copies(&mut self, v: bool) -> &mut Self

Description

-z

Includes any files that have lazy copies or are lazy copies. See Criteria with -z.

pub fn include_lazy_copies(self, v: bool) -> Self

Description

-z

Includes any files that have lazy copies or are lazy copies. See Criteria with -z.