Changes

Struct Changes 

pub struct Changes<L = Unselected> { /* private fields */ }
p4 [g-opts] changes [-i -t -l -L -f] [-c client] [ -e changelist#][-m max] [-r] [-s status] [-u user | --me] [file[RevRange] ...] [--stream | --nostream]

List submitted and pending changelists.

The command p4 changelists is an alias for p4 changes.

The L type parameter tracks the -l / -L long output mode at compile time; see FullDescription, TruncatedDescription, Self::long_output_full, and Self::long_output_truncated.

Implementations

Source

impl Changes<Unselected>

pub fn new(bin: impl Into<PathBuf>, global_opts: GlobalOpts) -> Self

Creates a new p4 changes command.

bin is the path to the Perforce command-line executable.

pub fn long_output_full(self) -> Changes<FullDescription>

Description

-l

List long output, with the full text of each changelist description.

Transitions this command to the FullDescription state.

pub fn long_output_truncated(self) -> Changes<TruncatedDescription>

Description

-L

List long output, with the full text of each changelist description truncated at 250 characters.

Transitions this command to the TruncatedDescription state.

Source

impl<L: ExclusiveOption> Changes<L>

pub fn get_global_opts(&self) -> &GlobalOpts

Description

g-opts

See Global options.

pub fn set_global_opts(&mut self, v: GlobalOpts) -> &mut Self

Description

g-opts

See Global options.

pub fn global_opts(self, v: GlobalOpts) -> Self

Description

g-opts

See Global options.

pub fn get_filter_clients(&self) -> Option<&[String]>

Description

-c client

List only changes made from the named client workspace. This option can be repeated to filter for multiple clients.

pub fn set_filter_client(&mut self, v: impl Into<String>) -> &mut Self

Description

-c client

List only changes made from the named client workspace. This option can be repeated to filter for multiple clients.

pub fn filter_client(self, v: impl Into<String>) -> Self

Description

-c client

List only changes made from the named client workspace. This option can be repeated to filter for multiple clients.

pub fn get_min_change_list(&self) -> Option<&String>

Description

-e changelist#

Display only changes where the changelist number is equal to, or higher than, the specified changelist number.

pub fn set_min_change_list(&mut self, v: impl Into<String>) -> &mut Self

Description

-e changelist#

Display only changes where the changelist number is equal to, or higher than, the specified changelist number.

pub fn min_change_list(self, v: impl Into<String>) -> Self

Description

-e changelist#

Display only changes where the changelist number is equal to, or higher than, the specified changelist number.

pub fn get_include_restricted(&self) -> bool

Description

-f

View restricted changes (requires admin permission).

pub fn set_include_restricted(&mut self, v: bool) -> &mut Self

Description

-f

View restricted changes (requires admin permission).

pub fn include_restricted(self, v: bool) -> Self

Description

-f

View restricted changes (requires admin permission).

pub fn get_include_integrated(&self) -> bool

Description

-i

Include changelists that affected files that were integrated with the specified files.

pub fn set_include_integrated(&mut self, v: bool) -> &mut Self

Description

-i

Include changelists that affected files that were integrated with the specified files.

pub fn include_integrated(self, v: bool) -> Self

Description

-i

Include changelists that affected files that were integrated with the specified files.

pub fn get_limit(&self) -> Option<u64>

Description

-m max

List only the highest numbered max changes.

pub fn set_limit(&mut self, v: u64) -> &mut Self

Description

-m max

List only the highest numbered max changes.

pub fn limit(self, v: u64) -> Self

Description

-m max

List only the highest numbered max changes.

pub fn get_reverse_order(&self) -> bool

Description

-r

Reverse the order of the list, earliest first instead of most recent first.

pub fn set_reverse_order(&mut self, v: bool) -> &mut Self

Description

-r

Reverse the order of the list, earliest first instead of most recent first.

pub fn reverse_order(self, v: bool) -> Self

Description

-r

Reverse the order of the list, earliest first instead of most recent first.

pub fn get_status(&self) -> Option<Status>

Description

-s status

Limit the list to the changelists with the specified status: pending, submitted, or shelved.

pub fn set_status(&mut self, v: Status) -> &mut Self

Description

-s status

Limit the list to the changelists with the specified status: pending, submitted, or shelved.

pub fn status(self, v: Status) -> Self

Description

-s status

Limit the list to the changelists with the specified status: pending, submitted, or shelved.

pub fn get_include_time(&self) -> bool

Description

-t

Display the time as well as the date of each change.

pub fn set_include_time(&mut self, v: bool) -> &mut Self

Description

-t

Display the time as well as the date of each change.

pub fn include_time(self, v: bool) -> Self

Description

-t

Display the time as well as the date of each change.

pub fn get_filter_users(&self) -> Option<&[User]>

Description

-u user / --me

List only changes made from the named user, or, with User::Me, the current user (equivalent to -u $P4USER). This option can be repeated to filter for multiple users.

pub fn set_filter_user(&mut self, v: impl Into<String>) -> &mut Self

Description

-u user

List only changes made from the named user. This option can be repeated to filter for multiple users.

pub fn filter_user(self, v: impl Into<String>) -> Self

Description

-u user

List only changes made from the named user. This option can be repeated to filter for multiple users.

pub fn set_filter_me(&mut self) -> &mut Self

Description

--me

Equivalent to -u $P4USER.

pub fn filter_me(self) -> Self

Description

--me

Equivalent to -u $P4USER.

pub fn get_client_case_insensitive(&self) -> bool

Description

--client-case-insensitive

Makes the -c client search pattern case-insensitive, even on a case-sensitive server.

pub fn set_client_case_insensitive(&mut self, v: bool) -> &mut Self

Description

--client-case-insensitive

Makes the -c client search pattern case-insensitive, even on a case-sensitive server.

pub fn client_case_insensitive(self, v: bool) -> Self

Description

--client-case-insensitive

Makes the -c client search pattern case-insensitive, even on a case-sensitive server.

pub fn get_stream(&self) -> Option<bool>

Description

--stream / --nostream

With true, display only changes that contain a stream spec (--stream). With false, display only changes that do not contain a stream spec (--nostream).

pub fn set_stream(&mut self, v: bool) -> &mut Self

Description

--stream / --nostream

With true, display only changes that contain a stream spec (--stream). With false, display only changes that do not contain a stream spec (--nostream).

pub fn stream(self, v: bool) -> Self

Description

--stream / --nostream

With true, display only changes that contain a stream spec (--stream). With false, display only changes that do not contain a stream spec (--nostream).