Describe

Struct Describe 

pub struct Describe<M = Unselected> { /* private fields */ }
p4 [g-opts] describe [-doptions] [-a -f -I -m -O -s -S] changelist ...

Provides information about changelists, as well as files in the changelists, and the path of the open stream, if a stream is open.

The M type parameter tracks the output mode at compile time. The default Unselected state offers neither -s nor -a/-d; Self::short_summary_output transitions to the ShortSummaryMode state, while Self::display_added_text_content and Self::diff_options transition to the DetailDiffMode state.

Implementations

Source

impl Describe<Unselected>

pub fn new(bin: impl Into<PathBuf>, global_opts: GlobalOpts) -> Self

Creates a new p4 describe command.

bin is the path to the Perforce command-line executable.

pub fn short_summary_output(self) -> Describe<ShortSummaryMode>

Description

-s

Display a shortened output that excludes the diffs of the files.

Transitions this command to the ShortSummaryMode state.

pub fn display_added_text_content(self, v: bool) -> Describe<DetailDiffMode>

Description

-a

For text files only (ignores binary files):

  • For shelved files, shows the content for “open for add” (pending) files.
  • For submitted files, shows the content of added files.

Transitions this command to the DetailDiffMode state with -a set according to v.

pub fn diff_options(self, v: impl Into<DiffOptions>) -> Describe<DetailDiffMode>

Description

-doptions

Runs the diff routine with one of a subset of the standard UNIX diff options. See Usage notes for an option listing.

Transitions this command to the DetailDiffMode state with the diff options set.

Source

impl<M: ExclusiveOption> Describe<M>

pub fn get_global_opts(&self) -> &GlobalOpts

Description

g-opts

See Global options.

pub fn set_global_opts(&mut self, v: GlobalOpts) -> &mut Self

Description

g-opts

See Global options.

pub fn global_opts(self, v: GlobalOpts) -> Self

Description

g-opts

See Global options.

pub fn get_force_restricted(&self) -> bool

Description

-f

Force the display of descriptions for restricted changelists. This option requires admin permission.

pub fn set_force_restricted(&mut self, v: bool) -> &mut Self

Description

-f

Force the display of descriptions for restricted changelists. This option requires admin permission.

pub fn force_restricted(self, v: bool) -> Self

Description

-f

Force the display of descriptions for restricted changelists. This option requires admin permission.

pub fn get_use_identity(&self) -> bool

Description

-I

Specifies that the changelist number is the Identity field of a changelist.

pub fn set_use_identity(&mut self, v: bool) -> &mut Self

Description

-I

Specifies that the changelist number is the Identity field of a changelist.

pub fn use_identity(self, v: bool) -> Self

Description

-I

Specifies that the changelist number is the Identity field of a changelist.

pub fn get_limit(&self) -> Option<u64>

Description

-m max

Limits files to the first max number of files. The following example alphabetically lists (and diffs) two files affected by changelist 765 and two files affected by changelist 987: p4 describe -m 2 765 987

pub fn set_limit(&mut self, v: u64) -> &mut Self

Description

-m max

Limits files to the first max number of files. The following example alphabetically lists (and diffs) two files affected by changelist 765 and two files affected by changelist 987: p4 describe -m 2 765 987

pub fn limit(self, v: u64) -> Self

Description

-m max

Limits files to the first max number of files. The following example alphabetically lists (and diffs) two files affected by changelist 765 and two files affected by changelist 987: p4 describe -m 2 765 987

pub fn get_use_original_number(&self) -> bool

Description

-O

If a changelist was renumbered on submit, and you know only the original changelist number, use -O and the original changelist number to describe the changelist.

pub fn set_use_original_number(&mut self, v: bool) -> &mut Self

Description

-O

If a changelist was renumbered on submit, and you know only the original changelist number, use -O and the original changelist number to describe the changelist.

pub fn use_original_number(self, v: bool) -> Self

Description

-O

If a changelist was renumbered on submit, and you know only the original changelist number, use -O and the original changelist number to describe the changelist.

pub fn get_include_shelved_files(&self) -> bool

Description

-S

Lists files that are shelved for the pending changelist and displays diffs of the files against their previous revision.

pub fn set_include_shelved_files(&mut self, v: bool) -> &mut Self

Description

-S

Lists files that are shelved for the pending changelist and displays diffs of the files against their previous revision.

pub fn include_shelved_files(self, v: bool) -> Self

Description

-S

Lists files that are shelved for the pending changelist and displays diffs of the files against their previous revision.

Source

impl Describe<DetailDiffMode>

pub fn get_diff_options(&self) -> Option<&DiffOptions>

Description

-doptions

Runs the diff routine with one of a subset of the standard UNIX diff options. See Usage notes for an option listing.

pub fn set_diff_options(&mut self, v: impl Into<DiffOptions>) -> &mut Self

Description

-doptions

Runs the diff routine with one of a subset of the standard UNIX diff options. See Usage notes for an option listing.

pub fn get_display_added_text_content(&self) -> bool

Description

-a

For text files only (ignores binary files):

  • For shelved files, shows the content for “open for add” (pending) files.
  • For submitted files, shows the content of added files.
pub fn set_display_added_text_content(&mut self, v: bool) -> &mut Self

Description

-a

For text files only (ignores binary files):

  • For shelved files, shows the content for “open for add” (pending) files.
  • For submitted files, shows the content of added files.