pub struct StreamSpecMode;Expand description
Stream spec mode of p4 diff (-As): diff a privately edited stream
spec against another version of the same stream spec, or diff two
arbitrary stream specs against each other.
Entered with Diff::stream_spec_mode; the stream spec to compare
against is passed as the argument of the spawned command.