Module diff2

Module diff2 

Structs

BranchMode
The -b branch sub-mode of the DepotContent state: diff files in two branched codelines through a branch mapping.
DepotContent
The depot content modes of p4 diff2: the default form comparing two depot paths, or the -b branch / -S stream sub-modes.
Diff2
p4 [g-opts] diff2 [-doptions] [-Od -q -t -u] file1[rev] file2[rev]
StreamMode
The -S stream sub-mode of the DepotContent state: diff a stream with its parent.
StreamSpecMode
Stream spec mode of p4 diff2 (-As): diff two arbitrary stream specs against each other.