pub enum Diff2Parameters<'a> {
Full {
from: &'a OsStr,
to: &'a OsStr,
},
To(&'a OsStr),
None,
}Expand description
File arguments of the DepotContent state’s BranchMode and
StreamMode sub-modes.
The prototype [[fromfile[rev]] tofile[rev]] allows either no file
arguments (Diff2Parameters::None), the target side only
(Diff2Parameters::To), or both sides (Diff2Parameters::Full).
Variants
Full
Diff fromfile[rev] against tofile[rev].
To(&'a OsStr)
Diff the whole branch or stream, limited to the target side
tofile[rev].
None
Diff the whole branch or stream without limiting files.