LongOutput

Enum LongOutput 

pub enum LongOutput {
    Default,
    Truncated,
}
Long output mode for changelist descriptions shared by commands such as p4 changes and p4 filelog.

By default, only the first 30 (or 31) characters of the description are shown.

Variants



Default

Show the full text of each changelist description (-l).



Truncated

Show the full text truncated at 250 characters (-L).

Implementations

Source

impl LongOutput

pub fn as_str(&self) -> &'static str

Returns the command-line flag for this long output mode.