pub enum WhitespaceHandling {
None,
IgnoreLineEndings,
IgnoreChangesWithinWhitespace,
IgnoreAllWhitespace,
}Expand description
Whitespace handling of the diff routine passed via -doptions.
This is one of two orthogonal dimensions of DiffOptions (the other
being DiffFormat). The
IgnoreChangesWithinWhitespace
and IgnoreAllWhitespace
variants each imply
IgnoreLineEndings.
Variants
None
No whitespace handling.
IgnoreLineEndings
Ignore line-ending (CR/LF) convention when finding diffs (-dl).
IgnoreChangesWithinWhitespace
Ignore changes made within whitespace (-db); implies -dl.
IgnoreAllWhitespace
Ignore whitespace altogether (-dw); implies -dl.