Module filelog

Module filelog 

Structs

DisplayContentHistory
Content history mode of p4 filelog (-h): display file content history instead of file name history.
FileLog
Print detailed information about the revisions of files.
FullDescription
Full description output of p4 filelog (-l): list long output, with the full text of each changelist description.
TruncatedDescription
Truncated description output of p4 filelog (-L): list long output, with the full text of each changelist description truncated at 250 characters.