FileLog

Struct FileLog 

pub struct FileLog<L = Unselected, H = Unselected> { /* private fields */ }
Print detailed information about the revisions of files.

The L type parameter tracks the changelist description output at compile time: Self::full_description transitions to the FullDescription state and Self::truncated_description transitions to the TruncatedDescription state. The H type parameter tracks whether file content history is displayed: Self::content_history transitions to the DisplayContentHistory state.

Implementations

Source

impl FileLog<Unselected, Unselected>

pub fn new(bin: impl Into<PathBuf>, global_opts: GlobalOpts) -> Self

Creates a new p4 filelog command.

bin is the path to the Perforce command-line executable.

Source

impl<H: ExclusiveOption> FileLog<Unselected, H>

pub fn full_description(self) -> FileLog<FullDescription, H>

Description

-l

List long output, with the full text of each changelist description.

Transitions this command to the FullDescription state.

pub fn truncated_description(self) -> FileLog<TruncatedDescription, H>

Description

-L

List long output, with the full text of each changelist description truncated at 250 characters.

Transitions this command to the TruncatedDescription state.

Source

impl<L: ExclusiveOption> FileLog<L, Unselected>

pub fn content_history(self) -> FileLog<L, DisplayContentHistory>

Description

-h

Display file content history instead of file name history.

Transitions this command to the DisplayContentHistory state, which unlocks the -p option.

Source

impl<L: ExclusiveOption, H: ExclusiveOption> FileLog<L, H>

pub fn get_global_opts(&self) -> &GlobalOpts

Description

g-opts

See Global options.

pub fn set_global_opts(&mut self, v: GlobalOpts) -> &mut Self

Description

g-opts

See Global options.

pub fn global_opts(self, v: GlobalOpts) -> Self

Description

g-opts

See Global options.

pub fn get_changelist(&self) -> Option<&String>

Description

-c change

Display only files submitted at the specified changelist number.

pub fn set_changelist(&mut self, v: impl Into<String>) -> &mut Self

Description

-c change

Display only files submitted at the specified changelist number.

pub fn changelist(self, v: impl Into<String>) -> Self

Description

-c change

Display only files submitted at the specified changelist number.

pub fn get_follow_branches(&self) -> bool

Description

-i

Follow file history across branches.

pub fn set_follow_branches(&mut self, v: bool) -> &mut Self

Description

-i

Follow file history across branches.

pub fn follow_branches(self, v: bool) -> Self

Description

-i

Follow file history across branches.

pub fn get_limit(&self) -> Option<u64>

Description

-m max

List only the first max changes per file output.

pub fn set_limit(&mut self, v: u64) -> &mut Self

Description

-m max

List only the first max changes per file output.

pub fn limit(self, v: u64) -> Self

Description

-m max

List only the first max changes per file output.

pub fn get_ignore_non_contributory(&self) -> bool

Description

-s

Display a shortened form of output by ignoring non-contributory integrations.

pub fn set_ignore_non_contributory(&mut self, v: bool) -> &mut Self

Description

-s

Display a shortened form of output by ignoring non-contributory integrations.

pub fn ignore_non_contributory(self, v: bool) -> Self

Description

-s

Display a shortened form of output by ignoring non-contributory integrations.

pub fn get_include_time(&self) -> bool

Description

-t

Display the time as well as the date.

pub fn set_include_time(&mut self, v: bool) -> &mut Self

Description

-t

Display the time as well as the date.

pub fn include_time(self, v: bool) -> Self

Description

-t

Display the time as well as the date.

Source

impl<L: ExclusiveOption> FileLog<L, DisplayContentHistory>

pub fn get_skip_promoted_tasks(&self) -> bool

Description

-p

When used with the -h option, do not follow content of promoted task streams.

pub fn set_skip_promoted_tasks(&mut self, v: bool) -> &mut Self

Description

-p

When used with the -h option, do not follow content of promoted task streams.

pub fn skip_promoted_tasks(self, v: bool) -> Self

Description

-p

When used with the -h option, do not follow content of promoted task streams.