Where

Struct Where 

pub struct Where { /* private fields */ }
p4 [g-opts] where [file ...]

Show how the specified files are mapped by the client view.

p4 where uses the client view and root to print files locations relative to the top of the depot, relative to the top of the client workspace, and relative to the top of the local OS directory tree. The client mappings are set by the p4 client command. The p4 where command does not check to see whether the file exists. Instead, it reports where the file would be located if it did exist.

The command accepts wildcards, such as p4 where *.html

For each file provided as a parameter, a set of mappings is output. Each set of mappings consists of:

  • the filename in depot syntax. such as //depot/project1/my-file.html
  • the filename in client syntax, such as //maria/depot/project1/my-file.html
  • the filename in local syntax, which is the local operating system path, such as C:\Users\maria\project1\my-file.html

Implementations

Source

impl Where

pub fn new(bin: impl Into<PathBuf>, global_opts: GlobalOpts) -> Self

Creates a new p4 where command.

bin is the path to the Perforce command-line executable.

pub fn get_global_opts(&self) -> &GlobalOpts

Description

g-opts

See Global options.

pub fn set_global_opts(&mut self, v: GlobalOpts) -> &mut Self

Description

g-opts

See Global options.

pub fn global_opts(self, v: GlobalOpts) -> Self

Description

g-opts

See Global options.