Skip to main contentModule cmd
Source pub use add::Add;pub use admin::AdminEntry;pub use aliases::Aliases;pub use annotate::Annotate;pub use archive::Archive;pub use attribute::Attribute;pub use changes::Changes;pub use describe::Describe;pub use diff::Diff;pub use diff::DisplayOptions;pub use diff2::Diff2;pub use edit::Edit;pub use filelog::FileLog;pub use print::Print;pub use sync::Sync;pub use where::Where;
- add
- admin
- aliases
- annotate
- archive
- attribute
- changes
- describe
- diff
- diff2
- edit
- filelog
- print
- sync
- where
- DiffOptionsBuilder
- Builder for
DiffOptions, shared by commands such as p4 diff,
p4 diff2, p4 describe, and p4 annotate. - DiffOptionsRawMode
- The raw (
Raw) state of a DiffOptionsBuilder,
holding the option string passed verbatim to the underlying diff routine. - DiffOptionsTypedMode
- The structured (
Typed) state of a
DiffOptionsBuilder, holding the selected DiffFormat and
WhitespaceHandling. - Unselected
- The default “no option selected” variant, shared by every
ExclusiveOption group.
- DiffFormat
- Output format of the diff routine passed via
-doptions. - DiffOptions
- Diff routine options passed via
-doptions, shared by commands such as
p4 diff, p4 diff2, p4 describe, and p4 annotate. - LongOutput
- Long output mode for changelist descriptions shared by commands such as
p4 changes and p4 filelog. - WhitespaceHandling
- Whitespace handling of the diff routine passed via
-doptions.
- ExclusiveOption
- Marker trait for a mutually exclusive option group.
- SubCommand