pub struct Changes<L = Unselected> { /* private fields */ }Expand description
p4 [g-opts] changes [-i -t -l -L -f] [-c client] [ -e changelist#][-m max] [-r] [-s status] [-u user | --me] [file[RevRange] ...] [--stream | --nostream]
List submitted and pending changelists.
The command p4 changelists is an alias for p4 changes.
The L type parameter tracks the -l / -L long output mode at
compile time; see FullDescription, TruncatedDescription,
Self::long_output_full, and Self::long_output_truncated.
Implementations
Sourceimpl Changes<Unselected>
impl Changes<Unselected>
Sourcepub fn new(bin: impl Into<PathBuf>, global_opts: GlobalOpts) -> Self
pub fn new(bin: impl Into<PathBuf>, global_opts: GlobalOpts) -> Self
Creates a new p4 changes command.
bin is the path to the Perforce command-line executable.
Sourcepub fn long_output_full(self) -> Changes<FullDescription>
pub fn long_output_full(self) -> Changes<FullDescription>
Description
-l
List long output, with the full text of each changelist description.
Transitions this command to the FullDescription state.
Sourcepub fn long_output_truncated(self) -> Changes<TruncatedDescription>
pub fn long_output_truncated(self) -> Changes<TruncatedDescription>
Description
-L
List long output, with the full text of each changelist description truncated at 250 characters.
Transitions this command to the TruncatedDescription state.
Sourceimpl<L: ExclusiveOption> Changes<L>
impl<L: ExclusiveOption> Changes<L>
Sourcepub fn get_global_opts(&self) -> &GlobalOpts
pub fn get_global_opts(&self) -> &GlobalOpts
Sourcepub fn set_global_opts(&mut self, v: GlobalOpts) -> &mut Self
pub fn set_global_opts(&mut self, v: GlobalOpts) -> &mut Self
Sourcepub fn global_opts(self, v: GlobalOpts) -> Self
pub fn global_opts(self, v: GlobalOpts) -> Self
Sourcepub fn get_filter_clients(&self) -> Option<&[String]>
pub fn get_filter_clients(&self) -> Option<&[String]>
Description
-c client
List only changes made from the named client workspace. This option can be repeated to filter for multiple clients.
Sourcepub fn set_filter_client(&mut self, v: impl Into<String>) -> &mut Self
pub fn set_filter_client(&mut self, v: impl Into<String>) -> &mut Self
Description
-c client
List only changes made from the named client workspace. This option can be repeated to filter for multiple clients.
Sourcepub fn filter_client(self, v: impl Into<String>) -> Self
pub fn filter_client(self, v: impl Into<String>) -> Self
Description
-c client
List only changes made from the named client workspace. This option can be repeated to filter for multiple clients.
Sourcepub fn get_min_change_list(&self) -> Option<&String>
pub fn get_min_change_list(&self) -> Option<&String>
Description
-e changelist#
Display only changes where the changelist number is equal to, or higher than, the specified changelist number.
Sourcepub fn set_min_change_list(&mut self, v: impl Into<String>) -> &mut Self
pub fn set_min_change_list(&mut self, v: impl Into<String>) -> &mut Self
Description
-e changelist#
Display only changes where the changelist number is equal to, or higher than, the specified changelist number.
Sourcepub fn min_change_list(self, v: impl Into<String>) -> Self
pub fn min_change_list(self, v: impl Into<String>) -> Self
Description
-e changelist#
Display only changes where the changelist number is equal to, or higher than, the specified changelist number.
Sourcepub fn get_include_restricted(&self) -> bool
pub fn get_include_restricted(&self) -> bool
Sourcepub fn set_include_restricted(&mut self, v: bool) -> &mut Self
pub fn set_include_restricted(&mut self, v: bool) -> &mut Self
Sourcepub fn include_restricted(self, v: bool) -> Self
pub fn include_restricted(self, v: bool) -> Self
Sourcepub fn get_include_integrated(&self) -> bool
pub fn get_include_integrated(&self) -> bool
Description
-i
Include changelists that affected files that were integrated with the specified files.
Sourcepub fn set_include_integrated(&mut self, v: bool) -> &mut Self
pub fn set_include_integrated(&mut self, v: bool) -> &mut Self
Description
-i
Include changelists that affected files that were integrated with the specified files.
Sourcepub fn include_integrated(self, v: bool) -> Self
pub fn include_integrated(self, v: bool) -> Self
Description
-i
Include changelists that affected files that were integrated with the specified files.
Sourcepub fn get_reverse_order(&self) -> bool
pub fn get_reverse_order(&self) -> bool
Sourcepub fn set_reverse_order(&mut self, v: bool) -> &mut Self
pub fn set_reverse_order(&mut self, v: bool) -> &mut Self
Sourcepub fn reverse_order(self, v: bool) -> Self
pub fn reverse_order(self, v: bool) -> Self
Sourcepub fn get_status(&self) -> Option<Status>
pub fn get_status(&self) -> Option<Status>
Description
-s status
Limit the list to the changelists with the specified status:
pending, submitted, or shelved.
Sourcepub fn set_status(&mut self, v: Status) -> &mut Self
pub fn set_status(&mut self, v: Status) -> &mut Self
Description
-s status
Limit the list to the changelists with the specified status:
pending, submitted, or shelved.
Sourcepub fn status(self, v: Status) -> Self
pub fn status(self, v: Status) -> Self
Description
-s status
Limit the list to the changelists with the specified status:
pending, submitted, or shelved.
Sourcepub fn get_include_time(&self) -> bool
pub fn get_include_time(&self) -> bool
Sourcepub fn set_include_time(&mut self, v: bool) -> &mut Self
pub fn set_include_time(&mut self, v: bool) -> &mut Self
Sourcepub fn include_time(self, v: bool) -> Self
pub fn include_time(self, v: bool) -> Self
Sourcepub fn get_filter_users(&self) -> Option<&[User]>
pub fn get_filter_users(&self) -> Option<&[User]>
Sourcepub fn set_filter_user(&mut self, v: impl Into<String>) -> &mut Self
pub fn set_filter_user(&mut self, v: impl Into<String>) -> &mut Self
Description
-u user
List only changes made from the named user. This option can be repeated to filter for multiple users.
Sourcepub fn filter_user(self, v: impl Into<String>) -> Self
pub fn filter_user(self, v: impl Into<String>) -> Self
Description
-u user
List only changes made from the named user. This option can be repeated to filter for multiple users.
Sourcepub fn set_filter_me(&mut self) -> &mut Self
pub fn set_filter_me(&mut self) -> &mut Self
Sourcepub fn get_client_case_insensitive(&self) -> bool
pub fn get_client_case_insensitive(&self) -> bool
Description
--client-case-insensitive
Makes the -c client search pattern case-insensitive, even on a
case-sensitive server.
Sourcepub fn set_client_case_insensitive(&mut self, v: bool) -> &mut Self
pub fn set_client_case_insensitive(&mut self, v: bool) -> &mut Self
Description
--client-case-insensitive
Makes the -c client search pattern case-insensitive, even on a
case-sensitive server.
Sourcepub fn client_case_insensitive(self, v: bool) -> Self
pub fn client_case_insensitive(self, v: bool) -> Self
Description
--client-case-insensitive
Makes the -c client search pattern case-insensitive, even on a
case-sensitive server.
Sourcepub fn get_stream(&self) -> Option<bool>
pub fn get_stream(&self) -> Option<bool>
Description
--stream / --nostream
With true, display only changes that contain a stream spec
(--stream). With false, display only changes that do not
contain a stream spec (--nostream).
Sourcepub fn set_stream(&mut self, v: bool) -> &mut Self
pub fn set_stream(&mut self, v: bool) -> &mut Self
Description
--stream / --nostream
With true, display only changes that contain a stream spec
(--stream). With false, display only changes that do not
contain a stream spec (--nostream).