Skip to main content Module diff Copy item path Source Diff p4 [g-opts] diff [-doptions] [-f -t -Od] [-m max] [-soptions] [file[rev] ...]StreamSpecMode Stream spec mode of p4 diff (-As): diff a privately edited stream
spec against another version of the same stream spec, or diff two
arbitrary stream specs against each other. WorkspaceDisplayMode The -soptions state of WorkspaceMode : a display filter is selected,
making -m max unavailable. WorkspaceMode Workspace content mode of p4 diff, comparing files in the client
workspace to revisions in the depot. WorkspaceRegularMode The -m max state of WorkspaceMode : a file limit is selected, making
-soptions unavailable. DisplayOptions Display options passed via the -soptions flag, producing a shorthand
list of files that match the filter instead of diffs.