Diff

Struct Diff 

pub struct Diff<M = Unselected> { /* private fields */ }
p4 [g-opts] diff [-doptions] [-f -t -Od] [-m max] [-soptions] [file[rev] ...]

p4 [g-opts] diff [-doptions] -As [streamname[@change]]

Diff utility for comparing workspace content to depot content. (For comparing two depot paths, see p4 diff2.) Also for stream spec comparison.

The M type parameter tracks the command mode at compile time. The default Unselected state offers neither the workspace content options nor -As; Self::force, Self::differing_only, and Self::diff_nontext transition to the WorkspaceMode state, while Self::stream_spec_mode transitions to the StreamSpecMode state.

Implementations

Source

impl Diff<Unselected>

pub fn new(bin: impl Into<PathBuf>, global_opts: GlobalOpts) -> Self

Creates a new p4 diff command.

bin is the path to the Perforce command-line executable.

pub fn force(self, v: bool) -> Diff<WorkspaceMode<Unselected>>

Description

-f

Force the diff (if no revision is specified, against the head revision), even when the client file is not open for edit.

Transitions this command to the WorkspaceMode state with -f set according to v.

Examples found in repository?
examples/diff.rs (line 37)
27fn main() -> std::io::Result<()> {
28    let p4 = P4Cli::default();
29
30    // Workspace mode: force a diff against head, use the unified format with
31    // whitespace-insensitive comparison, and limit output to the first 10
32    // files. `force(true)` transitions the command into `WorkspaceMode`, and
33    // `limit(10)` further transitions it into `WorkspaceRegularMode` (where
34    // `-soptions` is unavailable).
35    let mut diff = p4
36        .diff()
37        .force(true)
38        .diff_options(DiffOptionsBuilder::unified(None).ignore_all_whitespace())
39        .limit(10);
40
41    let files = [OsStr::new("//depot/project/src/...")];
42    let output = diff.output_with(&files)?;
43    println!("{}", String::from_utf8_lossy(&output.stdout));
44
45    // Display mode: instead of full diffs, list only the unopened files that
46    // differ from the depot. `display_options` transitions `WorkspaceMode`
47    // into `WorkspaceDisplayMode`, where `-m max` is unavailable.
48    let mut list_changed = p4
49        .diff()
50        .force(true)
51        .display_options(DisplayOptions::UnopenedChanged);
52
53    let output = list_changed.output_with(&files)?;
54    println!("{}", String::from_utf8_lossy(&output.stdout));
55
56    // Stream-spec mode: diff a privately edited stream spec against the head
57    // version of another stream. `stream_spec_mode` transitions the command
58    // into `StreamSpecMode`; the stream spec is passed to `spawn_with`.
59    let mut stream_diff = p4.diff().stream_spec_mode();
60    let mut child = stream_diff.spawn_with(Some("//streams/main@head"))?;
61    child.wait()?;
62
63    Ok(())
64}
pub fn differing_only(self, v: bool) -> Diff<WorkspaceMode<Unselected>>

Description

-Od

Limit output to only those files that differ.

Transitions this command to the WorkspaceMode state with -Od set according to v.

pub fn diff_nontext(self, v: bool) -> Diff<WorkspaceMode<Unselected>>

Description

-t

Diff the revisions even if the files are not of type text.

Transitions this command to the WorkspaceMode state with -t set according to v.

pub fn stream_spec_mode(self) -> Diff<StreamSpecMode>

Description

-As

Allows two arbitrary stream specs to be diffed against each other. Can be used with a streamname, or with a streamname at a specific changelist number.

Although this option requires the user have at least the list access to the stream path, it ignores any other entry in the protections table, including any minus sign (-) that would otherwise block the operation.

Transitions this command to the StreamSpecMode state. The stream spec to compare against is passed as the argument of the spawned command (ParameterizedSpawn::spawn_with); without one, the opened stream spec is diffed against its have version.

Examples found in repository?
examples/diff.rs (line 59)
27fn main() -> std::io::Result<()> {
28    let p4 = P4Cli::default();
29
30    // Workspace mode: force a diff against head, use the unified format with
31    // whitespace-insensitive comparison, and limit output to the first 10
32    // files. `force(true)` transitions the command into `WorkspaceMode`, and
33    // `limit(10)` further transitions it into `WorkspaceRegularMode` (where
34    // `-soptions` is unavailable).
35    let mut diff = p4
36        .diff()
37        .force(true)
38        .diff_options(DiffOptionsBuilder::unified(None).ignore_all_whitespace())
39        .limit(10);
40
41    let files = [OsStr::new("//depot/project/src/...")];
42    let output = diff.output_with(&files)?;
43    println!("{}", String::from_utf8_lossy(&output.stdout));
44
45    // Display mode: instead of full diffs, list only the unopened files that
46    // differ from the depot. `display_options` transitions `WorkspaceMode`
47    // into `WorkspaceDisplayMode`, where `-m max` is unavailable.
48    let mut list_changed = p4
49        .diff()
50        .force(true)
51        .display_options(DisplayOptions::UnopenedChanged);
52
53    let output = list_changed.output_with(&files)?;
54    println!("{}", String::from_utf8_lossy(&output.stdout));
55
56    // Stream-spec mode: diff a privately edited stream spec against the head
57    // version of another stream. `stream_spec_mode` transitions the command
58    // into `StreamSpecMode`; the stream spec is passed to `spawn_with`.
59    let mut stream_diff = p4.diff().stream_spec_mode();
60    let mut child = stream_diff.spawn_with(Some("//streams/main@head"))?;
61    child.wait()?;
62
63    Ok(())
64}
Source

impl<M> Diff<M>

pub fn get_diff_options(&self) -> Option<&DiffOptions>

Description

-doptions

Pass options to the underlying diff routine (see Usage notes for details).

pub fn set_diff_options(&mut self, v: impl Into<DiffOptions>) -> &mut Self

Description

-doptions

Pass options to the underlying diff routine (see Usage notes for details).

pub fn diff_options(self, v: impl Into<DiffOptions>) -> Self

Description

-doptions

Pass options to the underlying diff routine (see Usage notes for details).

Examples found in repository?
examples/diff.rs (line 38)
27fn main() -> std::io::Result<()> {
28    let p4 = P4Cli::default();
29
30    // Workspace mode: force a diff against head, use the unified format with
31    // whitespace-insensitive comparison, and limit output to the first 10
32    // files. `force(true)` transitions the command into `WorkspaceMode`, and
33    // `limit(10)` further transitions it into `WorkspaceRegularMode` (where
34    // `-soptions` is unavailable).
35    let mut diff = p4
36        .diff()
37        .force(true)
38        .diff_options(DiffOptionsBuilder::unified(None).ignore_all_whitespace())
39        .limit(10);
40
41    let files = [OsStr::new("//depot/project/src/...")];
42    let output = diff.output_with(&files)?;
43    println!("{}", String::from_utf8_lossy(&output.stdout));
44
45    // Display mode: instead of full diffs, list only the unopened files that
46    // differ from the depot. `display_options` transitions `WorkspaceMode`
47    // into `WorkspaceDisplayMode`, where `-m max` is unavailable.
48    let mut list_changed = p4
49        .diff()
50        .force(true)
51        .display_options(DisplayOptions::UnopenedChanged);
52
53    let output = list_changed.output_with(&files)?;
54    println!("{}", String::from_utf8_lossy(&output.stdout));
55
56    // Stream-spec mode: diff a privately edited stream spec against the head
57    // version of another stream. `stream_spec_mode` transitions the command
58    // into `StreamSpecMode`; the stream spec is passed to `spawn_with`.
59    let mut stream_diff = p4.diff().stream_spec_mode();
60    let mut child = stream_diff.spawn_with(Some("//streams/main@head"))?;
61    child.wait()?;
62
63    Ok(())
64}
Source

impl<M: ExclusiveOption> Diff<M>

pub fn get_global_opts(&self) -> &GlobalOpts

Description

g-opts

See Global options.

pub fn set_global_opts(&mut self, v: GlobalOpts) -> &mut Self

Description

g-opts

See Global options.

pub fn global_opts(self, v: GlobalOpts) -> Self

Description

g-opts

See Global options.

Source

impl<M> Diff<WorkspaceMode<M>>

pub fn get_force(&self) -> bool

Description

-f

Force the diff (if no revision is specified, against the head revision), even when the client file is not open for edit.

pub fn set_force(&mut self, v: bool) -> &mut Self

Description

-f

Force the diff (if no revision is specified, against the head revision), even when the client file is not open for edit.

pub fn force(self, v: bool) -> Self

Description

-f

Force the diff (if no revision is specified, against the head revision), even when the client file is not open for edit.

pub fn get_differing_only(&self) -> bool

Description

-Od

Limit output to only those files that differ.

pub fn set_differing_only(&mut self, v: bool) -> &mut Self

Description

-Od

Limit output to only those files that differ.

pub fn differing_only(self, v: bool) -> Self

Description

-Od

Limit output to only those files that differ.

pub fn get_diff_nontext(&self) -> bool

Description

-t

Diff the revisions even if the files are not of type text.

pub fn set_diff_nontext(&mut self, v: bool) -> &mut Self

Description

-t

Diff the revisions even if the files are not of type text.

pub fn diff_nontext(self, v: bool) -> Self

Description

-t

Diff the revisions even if the files are not of type text.

Source

impl Diff<WorkspaceMode<Unselected>>

pub fn display_options( self, v: DisplayOptions, ) -> Diff<WorkspaceMode<WorkspaceDisplayMode>>

Description

-soptions

Pass display options to the underlying diff routine (see Usage notes for details).

Transitions this command to the WorkspaceDisplayMode state with the display options set; -m max is unavailable in this state.

Examples found in repository?
examples/diff.rs (line 51)
27fn main() -> std::io::Result<()> {
28    let p4 = P4Cli::default();
29
30    // Workspace mode: force a diff against head, use the unified format with
31    // whitespace-insensitive comparison, and limit output to the first 10
32    // files. `force(true)` transitions the command into `WorkspaceMode`, and
33    // `limit(10)` further transitions it into `WorkspaceRegularMode` (where
34    // `-soptions` is unavailable).
35    let mut diff = p4
36        .diff()
37        .force(true)
38        .diff_options(DiffOptionsBuilder::unified(None).ignore_all_whitespace())
39        .limit(10);
40
41    let files = [OsStr::new("//depot/project/src/...")];
42    let output = diff.output_with(&files)?;
43    println!("{}", String::from_utf8_lossy(&output.stdout));
44
45    // Display mode: instead of full diffs, list only the unopened files that
46    // differ from the depot. `display_options` transitions `WorkspaceMode`
47    // into `WorkspaceDisplayMode`, where `-m max` is unavailable.
48    let mut list_changed = p4
49        .diff()
50        .force(true)
51        .display_options(DisplayOptions::UnopenedChanged);
52
53    let output = list_changed.output_with(&files)?;
54    println!("{}", String::from_utf8_lossy(&output.stdout));
55
56    // Stream-spec mode: diff a privately edited stream spec against the head
57    // version of another stream. `stream_spec_mode` transitions the command
58    // into `StreamSpecMode`; the stream spec is passed to `spawn_with`.
59    let mut stream_diff = p4.diff().stream_spec_mode();
60    let mut child = stream_diff.spawn_with(Some("//streams/main@head"))?;
61    child.wait()?;
62
63    Ok(())
64}
pub fn limit(self, max: u64) -> Diff<WorkspaceMode<WorkspaceRegularMode>>

Description

-m max

Limit output to diffs (or status) of only the first max files, unless the -s option is used, in which case the -m option is ignored.

Transitions this command to the WorkspaceRegularMode state with the limit set to max; -soptions is unavailable in this state.

Examples found in repository?
examples/diff.rs (line 39)
27fn main() -> std::io::Result<()> {
28    let p4 = P4Cli::default();
29
30    // Workspace mode: force a diff against head, use the unified format with
31    // whitespace-insensitive comparison, and limit output to the first 10
32    // files. `force(true)` transitions the command into `WorkspaceMode`, and
33    // `limit(10)` further transitions it into `WorkspaceRegularMode` (where
34    // `-soptions` is unavailable).
35    let mut diff = p4
36        .diff()
37        .force(true)
38        .diff_options(DiffOptionsBuilder::unified(None).ignore_all_whitespace())
39        .limit(10);
40
41    let files = [OsStr::new("//depot/project/src/...")];
42    let output = diff.output_with(&files)?;
43    println!("{}", String::from_utf8_lossy(&output.stdout));
44
45    // Display mode: instead of full diffs, list only the unopened files that
46    // differ from the depot. `display_options` transitions `WorkspaceMode`
47    // into `WorkspaceDisplayMode`, where `-m max` is unavailable.
48    let mut list_changed = p4
49        .diff()
50        .force(true)
51        .display_options(DisplayOptions::UnopenedChanged);
52
53    let output = list_changed.output_with(&files)?;
54    println!("{}", String::from_utf8_lossy(&output.stdout));
55
56    // Stream-spec mode: diff a privately edited stream spec against the head
57    // version of another stream. `stream_spec_mode` transitions the command
58    // into `StreamSpecMode`; the stream spec is passed to `spawn_with`.
59    let mut stream_diff = p4.diff().stream_spec_mode();
60    let mut child = stream_diff.spawn_with(Some("//streams/main@head"))?;
61    child.wait()?;
62
63    Ok(())
64}
Source

impl Diff<WorkspaceMode<WorkspaceDisplayMode>>

pub fn get_display_options(&self) -> &DisplayOptions

Description

-soptions

Pass display options to the underlying diff routine (see Usage notes for details).

pub fn set_display_options(&mut self, v: DisplayOptions) -> &mut Self

Description

-soptions

Pass display options to the underlying diff routine (see Usage notes for details).

Source

impl Diff<WorkspaceMode<WorkspaceRegularMode>>

pub fn get_limit(&self) -> u64

Description

-m max

Limit output to diffs (or status) of only the first max files, unless the -s option is used, in which case the -m option is ignored.

pub fn set_limit(&mut self, v: u64) -> &mut Self

Description

-m max

Limit output to diffs (or status) of only the first max files, unless the -s option is used, in which case the -m option is ignored.