DiffFormat

Enum DiffFormat 

pub enum DiffFormat {
    Default,
    Context(Option<u32>),
    Rcs,
    Summary,
    Unified(Option<u32>),
}
Output format of the diff routine passed via -doptions.

This is one of two orthogonal dimensions of DiffOptions (the other being WhitespaceHandling). Exactly one format may be selected; the Default variant corresponds to no format flag.

Variants



Default

Default diff output format (no format flag).



Context(Option<u32>)

Context output format (-dc[num]), showing num lines of context around the changes.



Rcs

RCS output format (-dn), showing additions and deletions with associated line ranges.



Summary

Summary output format (-ds), showing only the number of chunks and lines added, deleted, or changed.



Unified(Option<u32>)

Unified output format (-du[num]), showing added and deleted lines with num lines of context, in a form compatible with patch(1).