pub struct FileLog<L = Unselected, H = Unselected> { /* private fields */ }Expand description
Print detailed information about the revisions of files.
The L type parameter tracks the changelist description output at
compile time: Self::full_description transitions to the
FullDescription state and Self::truncated_description
transitions to the TruncatedDescription state. The H type
parameter tracks whether file content history is displayed:
Self::content_history transitions to the DisplayContentHistory
state.
Implementations
Sourceimpl FileLog<Unselected, Unselected>
impl FileLog<Unselected, Unselected>
Sourcepub fn new(bin: impl Into<PathBuf>, global_opts: GlobalOpts) -> Self
pub fn new(bin: impl Into<PathBuf>, global_opts: GlobalOpts) -> Self
Creates a new p4 filelog command.
bin is the path to the Perforce command-line executable.
Sourceimpl<H: ExclusiveOption> FileLog<Unselected, H>
impl<H: ExclusiveOption> FileLog<Unselected, H>
Sourcepub fn full_description(self) -> FileLog<FullDescription, H>
pub fn full_description(self) -> FileLog<FullDescription, H>
Description
-l
List long output, with the full text of each changelist description.
Transitions this command to the FullDescription state.
Sourcepub fn truncated_description(self) -> FileLog<TruncatedDescription, H>
pub fn truncated_description(self) -> FileLog<TruncatedDescription, H>
Description
-L
List long output, with the full text of each changelist description truncated at 250 characters.
Transitions this command to the TruncatedDescription state.
Sourceimpl<L: ExclusiveOption> FileLog<L, Unselected>
impl<L: ExclusiveOption> FileLog<L, Unselected>
Sourcepub fn content_history(self) -> FileLog<L, DisplayContentHistory>
pub fn content_history(self) -> FileLog<L, DisplayContentHistory>
Description
-h
Display file content history instead of file name history.
Transitions this command to the DisplayContentHistory state,
which unlocks the -p option.
Sourceimpl<L: ExclusiveOption, H: ExclusiveOption> FileLog<L, H>
impl<L: ExclusiveOption, H: ExclusiveOption> FileLog<L, H>
Sourcepub fn get_global_opts(&self) -> &GlobalOpts
pub fn get_global_opts(&self) -> &GlobalOpts
Sourcepub fn set_global_opts(&mut self, v: GlobalOpts) -> &mut Self
pub fn set_global_opts(&mut self, v: GlobalOpts) -> &mut Self
Sourcepub fn global_opts(self, v: GlobalOpts) -> Self
pub fn global_opts(self, v: GlobalOpts) -> Self
Sourcepub fn get_changelist(&self) -> Option<&String>
pub fn get_changelist(&self) -> Option<&String>
Sourcepub fn set_changelist(&mut self, v: impl Into<String>) -> &mut Self
pub fn set_changelist(&mut self, v: impl Into<String>) -> &mut Self
Sourcepub fn changelist(self, v: impl Into<String>) -> Self
pub fn changelist(self, v: impl Into<String>) -> Self
Sourcepub fn get_follow_branches(&self) -> bool
pub fn get_follow_branches(&self) -> bool
Sourcepub fn set_follow_branches(&mut self, v: bool) -> &mut Self
pub fn set_follow_branches(&mut self, v: bool) -> &mut Self
Sourcepub fn follow_branches(self, v: bool) -> Self
pub fn follow_branches(self, v: bool) -> Self
Sourcepub fn get_ignore_non_contributory(&self) -> bool
pub fn get_ignore_non_contributory(&self) -> bool
Sourcepub fn set_ignore_non_contributory(&mut self, v: bool) -> &mut Self
pub fn set_ignore_non_contributory(&mut self, v: bool) -> &mut Self
Sourcepub fn ignore_non_contributory(self, v: bool) -> Self
pub fn ignore_non_contributory(self, v: bool) -> Self
Sourcepub fn get_include_time(&self) -> bool
pub fn get_include_time(&self) -> bool
Sourcepub fn set_include_time(&mut self, v: bool) -> &mut Self
pub fn set_include_time(&mut self, v: bool) -> &mut Self
Sourcepub fn include_time(self, v: bool) -> Self
pub fn include_time(self, v: bool) -> Self
Sourceimpl<L: ExclusiveOption> FileLog<L, DisplayContentHistory>
impl<L: ExclusiveOption> FileLog<L, DisplayContentHistory>
Sourcepub fn get_skip_promoted_tasks(&self) -> bool
pub fn get_skip_promoted_tasks(&self) -> bool
Sourcepub fn set_skip_promoted_tasks(&mut self, v: bool) -> &mut Self
pub fn set_skip_promoted_tasks(&mut self, v: bool) -> &mut Self
Sourcepub fn skip_promoted_tasks(self, v: bool) -> Self
pub fn skip_promoted_tasks(self, v: bool) -> Self