Module sync

Module sync 

Structs

ForceRegularMode
Force execution sub-mode of RegularMode: entered when any of -f, -k, or -r is set.
ParallelConfig
Configuration for the --parallel option of p4 sync.
PopulateMode
Populate sub-mode of RegularMode (-p): populate a client workspace but do not update the have list.
PreviewNetworkTraffic
Preview mode of p4 sync (-N): display a summary of the expected network traffic associated with a sync, without performing the sync.
PreviewResult
Preview mode of p4 sync (-n): display the results of the sync without actually performing the sync.
RegularMode
Regular mode of p4 sync: the command forms that operate on the client workspace.
SafeCheckMode
Safe sync sub-mode of RegularMode (-s): compare the content in the client workspace against what was last synced and do not overwrite files that were modified outside of P4 Server’s control.
Sync
Update the client workspace to reflect the contents of the depot.
SyncTimeMode
Sync-time mode of p4 sync (-k --sync-time=N): update the have list to reflect the state of the depot at the given time without transferring files.

Enums

StreamSpecVersion
The --use-stream-change value controlling which stream specification version is used to generate the client view.