pub struct GlobalOpts { /* private fields */ }Expand description
Synopsis
Global options for Perforce commands; these options can be supplied on the command line before any Perforce command.
Implementations
Sourceimpl GlobalOpts
impl GlobalOpts
Sourceimpl GlobalOpts
impl GlobalOpts
Sourcepub fn get_batch_size(&self) -> Option<&u32>
pub fn get_batch_size(&self) -> Option<&u32>
Description
-b batchsize
Specifies a batch size (number of arguments) to use when processing a command from a file with the -x argfile option. By default, the batch size is 128.
Sourcepub fn set_batch_size(&mut self, v: u32) -> &mut Self
pub fn set_batch_size(&mut self, v: u32) -> &mut Self
Description
-b batchsize
Specifies a batch size (number of arguments) to use when processing a command from a file with the -x argfile option. By default, the batch size is 128.
Sourcepub fn batch_size(self, v: u32) -> Self
pub fn batch_size(self, v: u32) -> Self
Description
-b batchsize
Specifies a batch size (number of arguments) to use when processing a command from a file with the -x argfile option. By default, the batch size is 128.
Sourcepub fn get_client(&self) -> Option<&String>
pub fn get_client(&self) -> Option<&String>
Sourcepub fn set_client(&mut self, v: impl Into<String>) -> &mut Self
pub fn set_client(&mut self, v: impl Into<String>) -> &mut Self
Sourcepub fn get_dir(&self) -> Option<&PathBuf>
pub fn get_dir(&self) -> Option<&PathBuf>
Description
-d dir
Overrides any PWD setting (current working directory) and replaces it with the specified directory.
Sourcepub fn set_dir(&mut self, v: PathBuf) -> &mut Self
pub fn set_dir(&mut self, v: PathBuf) -> &mut Self
Description
-d dir
Overrides any PWD setting (current working directory) and replaces it with the specified directory.
Sourcepub fn dir(self, v: PathBuf) -> Self
pub fn dir(self, v: PathBuf) -> Self
Description
-d dir
Overrides any PWD setting (current working directory) and replaces it with the specified directory.
Sourcepub fn get_progress_indicators(&self) -> bool
pub fn get_progress_indicators(&self) -> bool
Description
-I
Specify that progress indicators, if available, are desired. This option is not compatible with the -s and -G options.
The progress indicator with the -I option is available for p4 -I move, p4 -I reconcile, p4 -I status, p4 -I submit, and p4 -I sync -q. For p4 -I reconcile and p4 -I status, the progress indicator shows four phases: reconcile add, reconcile edit, matching digest, and matching content. The add phase displays the number of directories scanned. All other phases show a percentage of files processed against total of candidate (deleted) files. For p4 -I move, the progress indicator shows two phases: matching digest, and matching content.
Sourcepub fn set_progress_indicators(&mut self, v: bool) -> &mut Self
pub fn set_progress_indicators(&mut self, v: bool) -> &mut Self
Description
-I
Specify that progress indicators, if available, are desired. This option is not compatible with the -s and -G options.
The progress indicator with the -I option is available for p4 -I move, p4 -I reconcile, p4 -I status, p4 -I submit, and p4 -I sync -q. For p4 -I reconcile and p4 -I status, the progress indicator shows four phases: reconcile add, reconcile edit, matching digest, and matching content. The add phase displays the number of directories scanned. All other phases show a percentage of files processed against total of candidate (deleted) files. For p4 -I move, the progress indicator shows two phases: matching digest, and matching content.
Sourcepub fn progress_indicators(self, v: bool) -> Self
pub fn progress_indicators(self, v: bool) -> Self
Description
-I
Specify that progress indicators, if available, are desired. This option is not compatible with the -s and -G options.
The progress indicator with the -I option is available for p4 -I move, p4 -I reconcile, p4 -I status, p4 -I submit, and p4 -I sync -q. For p4 -I reconcile and p4 -I status, the progress indicator shows four phases: reconcile add, reconcile edit, matching digest, and matching content. The add phase displays the number of directories scanned. All other phases show a percentage of files processed against total of candidate (deleted) files. For p4 -I move, the progress indicator shows two phases: matching digest, and matching content.
Sourcepub fn get_standard_in(&self) -> bool
pub fn get_standard_in(&self) -> bool
Description
-i
Although not global, the -i and -o options work with forms and represent standard in and standard out.
Sourcepub fn set_standard_in(&mut self, v: bool) -> &mut Self
pub fn set_standard_in(&mut self, v: bool) -> &mut Self
Description
-i
Although not global, the -i and -o options work with forms and represent standard in and standard out.
Sourcepub fn standard_in(self, v: bool) -> Self
pub fn standard_in(self, v: bool) -> Self
Description
-i
Although not global, the -i and -o options work with forms and represent standard in and standard out.
Sourcepub fn get_marshalled_formatted(&self) -> bool
pub fn get_marshalled_formatted(&self) -> bool
Sourcepub fn set_marshalled_formatted(&mut self, v: bool) -> &mut Self
pub fn set_marshalled_formatted(&mut self, v: bool) -> &mut Self
Sourcepub fn marshalled_formatted(self, v: bool) -> Self
pub fn marshalled_formatted(self, v: bool) -> Self
Sourcepub fn get_json_formatted(&self) -> bool
pub fn get_json_formatted(&self) -> bool
Sourcepub fn set_json_formatted(&mut self, v: bool) -> &mut Self
pub fn set_json_formatted(&mut self, v: bool) -> &mut Self
Sourcepub fn json_formatted(self, v: bool) -> Self
pub fn json_formatted(self, v: bool) -> Self
Sourcepub fn get_standard_out(&self) -> bool
pub fn get_standard_out(&self) -> bool
Description
-o
Although not global, the -i and -o options work with forms and represent standard in and standard out.
Sourcepub fn set_standard_out(&mut self, v: bool) -> &mut Self
pub fn set_standard_out(&mut self, v: bool) -> &mut Self
Description
-o
Although not global, the -i and -o options work with forms and represent standard in and standard out.
Sourcepub fn standard_out(self, v: bool) -> Self
pub fn standard_out(self, v: bool) -> Self
Description
-o
Although not global, the -i and -o options work with forms and represent standard in and standard out.
Sourcepub fn get_pass(&self) -> Option<&String>
pub fn get_pass(&self) -> Option<&String>
Description
-P pass
Enables a password (or ticket) to be passed on the command line, thus bypassing the password associated with P4PASSWD. If a valid ticket exists, using this option with an invalid pass causes access to be granted by the valid ticket.
Sourcepub fn set_pass(&mut self, v: impl Into<String>) -> &mut Self
pub fn set_pass(&mut self, v: impl Into<String>) -> &mut Self
Description
-P pass
Enables a password (or ticket) to be passed on the command line, thus bypassing the password associated with P4PASSWD. If a valid ticket exists, using this option with an invalid pass causes access to be granted by the valid ticket.
Sourcepub fn pass(self, v: impl Into<String>) -> Self
pub fn pass(self, v: impl Into<String>) -> Self
Description
-P pass
Enables a password (or ticket) to be passed on the command line, thus bypassing the password associated with P4PASSWD. If a valid ticket exists, using this option with an invalid pass causes access to be granted by the valid ticket.
Sourcepub fn get_retries(&self) -> Option<&u32>
pub fn get_retries(&self) -> Option<&u32>
Description
-r retries
Specifies the number of times to retry a command (notably, p4 sync) if the network times out.
Sourcepub fn set_retries(&mut self, v: u32) -> &mut Self
pub fn set_retries(&mut self, v: u32) -> &mut Self
Description
-r retries
Specifies the number of times to retry a command (notably, p4 sync) if the network times out.
Sourcepub fn retries(self, v: u32) -> Self
pub fn retries(self, v: u32) -> Self
Description
-r retries
Specifies the number of times to retry a command (notably, p4 sync) if the network times out.
Sourcepub fn get_prepend_descriptive(&self) -> bool
pub fn get_prepend_descriptive(&self) -> bool
Description
-s
Prepends a descriptive field (for example, text:, info:, error:, exit:) to each line of output produced by a P4 Server command. This is most often used when scripting.
Sourcepub fn set_prepend_descriptive(&mut self, v: bool) -> &mut Self
pub fn set_prepend_descriptive(&mut self, v: bool) -> &mut Self
Description
-s
Prepends a descriptive field (for example, text:, info:, error:, exit:) to each line of output produced by a P4 Server command. This is most often used when scripting.
Sourcepub fn prepend_descriptive(self, v: bool) -> Self
pub fn prepend_descriptive(self, v: bool) -> Self
Description
-s
Prepends a descriptive field (for example, text:, info:, error:, exit:) to each line of output produced by a P4 Server command. This is most often used when scripting.
Sourcepub fn get_argfile(&self) -> Option<&PathBuf>
pub fn get_argfile(&self) -> Option<&PathBuf>
Description
-x argfile
Instructs P4 Server to read arguments, one per line, from the specified file. If argfile is a single hyphen (-), instructs P4 Server to read from standard input instead of from a file.
Sourcepub fn set_argfile(&mut self, v: PathBuf) -> &mut Self
pub fn set_argfile(&mut self, v: PathBuf) -> &mut Self
Description
-x argfile
Instructs P4 Server to read arguments, one per line, from the specified file. If argfile is a single hyphen (-), instructs P4 Server to read from standard input instead of from a file.
Sourcepub fn argfile(self, v: PathBuf) -> Self
pub fn argfile(self, v: PathBuf) -> Self
Description
-x argfile
Instructs P4 Server to read arguments, one per line, from the specified file. If argfile is a single hyphen (-), instructs P4 Server to read from standard input instead of from a file.
Sourcepub fn get_charset(&self) -> Option<&String>
pub fn get_charset(&self) -> Option<&String>
Sourcepub fn set_charset(&mut self, v: impl Into<String>) -> &mut Self
pub fn set_charset(&mut self, v: impl Into<String>) -> &mut Self
Sourcepub fn get_command_charset(&self) -> Option<&String>
pub fn get_command_charset(&self) -> Option<&String>
Sourcepub fn set_command_charset(&mut self, v: impl Into<String>) -> &mut Self
pub fn set_command_charset(&mut self, v: impl Into<String>) -> &mut Self
Sourcepub fn command_charset(self, v: impl Into<String>) -> Self
pub fn command_charset(self, v: impl Into<String>) -> Self
Sourcepub fn get_language(&self) -> Option<&String>
pub fn get_language(&self) -> Option<&String>
Sourcepub fn set_language(&mut self, v: impl Into<String>) -> &mut Self
pub fn set_language(&mut self, v: impl Into<String>) -> &mut Self
Sourcepub fn get_tagged_format(&self) -> bool
pub fn get_tagged_format(&self) -> bool
Sourcepub fn set_tagged_format(&mut self, v: bool) -> &mut Self
pub fn set_tagged_format(&mut self, v: bool) -> &mut Self
Sourcepub fn tagged_format(self, v: bool) -> Self
pub fn tagged_format(self, v: bool) -> Self
Sourcepub fn get_quiet_mode(&self) -> bool
pub fn get_quiet_mode(&self) -> bool
Description
-q
Quiet mode, which suppresses informational messages and reports only warnings or errors.
Sourcepub fn set_quiet_mode(&mut self, v: bool) -> &mut Self
pub fn set_quiet_mode(&mut self, v: bool) -> &mut Self
Description
-q
Quiet mode, which suppresses informational messages and reports only warnings or errors.
Sourcepub fn quiet_mode(self, v: bool) -> Self
pub fn quiet_mode(self, v: bool) -> Self
Description
-q
Quiet mode, which suppresses informational messages and reports only warnings or errors.
Sourcepub fn get_debug_variable(&self) -> Option<&[String]>
pub fn get_debug_variable(&self) -> Option<&[String]>
Description
-v var
Debug level or configurable represented by var, such as: p4 -v 1 info or p4 -v net.autotune=0 info. This option can be specified more than once; each call appends another var.
Sourcepub fn set_debug_variable(&mut self, v: impl Into<String>) -> &mut Self
pub fn set_debug_variable(&mut self, v: impl Into<String>) -> &mut Self
Description
-v var
Debug level or configurable represented by var, such as: p4 -v 1 info or p4 -v net.autotune=0 info. This option can be specified more than once; each call appends another var.
Sourcepub fn debug_variable(self, v: impl Into<String>) -> Self
pub fn debug_variable(self, v: impl Into<String>) -> Self
Description
-v var
Debug level or configurable represented by var, such as: p4 -v 1 info or p4 -v net.autotune=0 info. This option can be specified more than once; each call appends another var.