pub struct P4Cli { /* private fields */ }Implementations
Sourceimpl P4Cli
impl P4Cli
Sourcepub fn new(bin: impl Into<PathBuf>, global_opts: GlobalOpts) -> Self
pub fn new(bin: impl Into<PathBuf>, global_opts: GlobalOpts) -> Self
Create a new Perforce command-line client.
bin is the path to the Perforce command-line executable.
Sourcepub fn global_opts(self, global_opts: GlobalOpts) -> Self
pub fn global_opts(self, global_opts: GlobalOpts) -> Self
Set the global options.
Sourcepub fn get_global_opts(&self) -> &GlobalOpts
pub fn get_global_opts(&self) -> &GlobalOpts
Get the global options.
Sourcepub fn set_global_opts(&mut self, global_opts: GlobalOpts)
pub fn set_global_opts(&mut self, global_opts: GlobalOpts)
Set the global options.
Sourcepub fn admin(&self) -> AdminEntry
pub fn admin(&self) -> AdminEntry
Perform administrative operations on the server.
Sourcepub fn aliases(&self) -> Aliases
pub fn aliases(&self) -> Aliases
Display command aliases that are currently defined in a .p4aliases file.
Sourcepub fn changelists(&self) -> Changes
pub fn changelists(&self) -> Changes
List submitted and pending changelists.
This is an alias for Self::changes, corresponding to the p4 changelists command.
Sourcepub fn print(&self) -> Print
pub fn print(&self) -> Print
Print the contents of depot file revisions.
Examples found in repository?
examples/print.rs (line 21)
15fn main() -> std::io::Result<()> {
16 let p4 = P4Cli::default();
17
18 // Chain builders: print all revisions of the first two matching files to
19 // a local output file, without the depot header line.
20 let mut print = p4
21 .print()
22 .all_revisions(true)
23 .quiet_mode(true)
24 .limit(2)
25 .redirect_output("print-output.txt");
26
27 // Run the command to completion and capture its output.
28 let file = Path::new("//depot/project/README.md");
29 let output = print.output_with(&[file.as_os_str()])?;
30 println!("{}", String::from_utf8_lossy(&output.stdout));
31
32 // Or stream the contents directly to the terminal with `spawn_with`.
33 let mut child = p4
34 .print()
35 .spawn_with(&[OsStr::new("//depot/project/README.md")])?;
36 child.wait()?;
37
38 Ok(())
39}Trait Implementations